@@ -78,7 +78,7 @@ class Forum(object):
             result['posts'] = first_page
         else:
             posts_before = self.posts(collection_id, folder, None, since_id-1 if since_id else None, 'DESC', 40)[::-1]
-            posts_next = self.posts(collection_id, folder, since_id+1 if since_id else None, None, 'ASC', 60)
+            posts_next = self.posts(collection_id, folder, since_id if since_id else None, None, 'ASC', 60)
             result['last'] = [int(math.floor(float(count)/20)), last_page[-1].id]
             result['posts'] = posts_next[:20]
             tpage = page - 1
